
###
###  Copyright 2000-2006 University of Illinois Board of Trustees
###  All rights reserved.
###
###  Makefile.PL - configuration rules for psgconf
###
###  Campus Information Technologies and Educational Services
###  University of Illinois at Urbana-Champaign
###


use ExtUtils::MakeMaker;
use Getopt::Long;

use strict;


my ($etc_dir, $share_dir);

$etc_dir	= '/etc';
$share_dir	= '$(PREFIX)/share/psgconf';

GetOptions(
	'etcdir=s'		=> \$etc_dir,
	'sharedir=s'		=> \$share_dir
) || die "Usage: $0 [--etcdir=DIR] [--sharedir=DIR]\n";


sub MY::postamble
{
	return 'SHARE_DIR	= ' . $share_dir . '
ETC_DIR		= ' . $etc_dir . '

install ::
	$(MKPATH) $(SHARE_DIR)/config
	$(CP) config/*.conf $(SHARE_DIR)/config
	$(MKPATH) $(SHARE_DIR)/files
	$(CP) files/rc.shutdown $(SHARE_DIR)/files
	$(CP) files/magic $(SHARE_DIR)/files

	$(SH) MAKE=$(MAKE) PREFIX=$(PREFIX) ./postinstall

svr4pkg:
	### Changes for when we move BASEDIR=/usr
	# $(MAKE) ETC_DIR=$(PREFIX)/local/etc SHARE_DIR=$(PREFIX)/local/share/psgconf INSTALLSCRIPT=$(PREFIX)/local/sbin INSTALLBIN=$(PREFIX)/local/sbin install
	# $(MV) $(PREFIX)/etc $(PREFIX)/local/.

	### Remove this line when we change BASEDIR=/usr
	$(CP) etc/psg.conf $(PREFIX)/etc/.

	if [ ! -f $(PREFIX)/prototype ]; then \
		echo "i copyright=./COPYRIGHT" > $(PREFIX)/prototype; \
		echo "i pkginfo=./pkginfo" >> $(PREFIX)/prototype; \
		if [ `uname -r` = "5.10" ]; then \
			echo "i depend=./depend.sol10" >> $(PREFIX)/prototype; \
		elif [ `uname -r` = "5.9" ]; then \
			echo "i depend=./depend.sol9" >> $(PREFIX)/prototype; \
		elif [ `uname -r` = "5.8" ]; then \
			echo "i depend=./depend.sol8" >> $(PREFIX)/prototype; \
		fi; \
		echo "i checkinstall=./preinstall" >> $(PREFIX)/prototype; \
		echo "i postinstall=./postinstall" >> $(PREFIX)/prototype; \
		/usr/bin/chown -R bin:bin $(PREFIX); \
		(cd $(PREFIX); find . -print|grep -v ./prototype|sort|pkgproto >> $(PREFIX)/prototype; )\
	fi
	$(CP) COPYRIGHT depend.sol* pkginfo preinstall postinstall $(PREFIX)
	/usr/bin/chown -R bin:bin $(PREFIX)/COPYRIGHT $(PREFIX)/depend.sol* $(PREFIX)/pkginfo $(PREFIX)/preinstall $(PREFIX)/postinstall
';
}


WriteMakefile(
	'NAME'		=> 'PSGConf',
	'DISTNAME'	=> 'psgconf',
	'VERSION_FROM'	=> 'sbin/psgconf',
	'PREREQ_PM'	=> {
				'Config::Objective'	=> '0.9.1',	# For DataStore::ConfigFile
				'NetAddr::IP'		=> 3.011,		# For Control::Network
				'Proc::ProcessTable'	=> 0.35,	# For Action::RestartDaemon
				'Unix::Mknod'	=> 0.02,			# For Action::MkNod
				'Text::Diff'	=> 0.35,			# For Action::File
				'version'		=> 0.29,			# For Action::PackageManager
				'AppConfig'	=> 1.55,			# For Action::GenerateFile::AppConfig
											# and DataStore::AppConfig
				($] < 5.80 ? (
				'Net::FTP'	=> 1.19,			# For Action::PackageManager::FTPArchive
				'Storable'	=> 2.04)			# For DataStore::Storable
				: ())
			   },
	'INSTALLSCRIPT'	=> '$(PREFIX)/sbin',
	'EXE_FILES'	=> [ qw(
				sbin/ConfigFile2Storable
				sbin/platform-name
				sbin/psgconf
				sbin/psgconf-import
			   ) ],
	## Add these new keywords supported since 5.005
	($] >= 5.005 ? (
	'ABSTRACT_FROM'	=> 'sbin/psgconf')
	: ()),
);


